Module

Trait Module 

pub trait Module {
    // Provided methods
    fn pre_timer(&mut self, _timer: TimerInfo) -> Result<Progress> { ... }
    fn post_timer(&mut self, _timer: TimerInfo) -> Result<Progress> { ... }
    fn warning(&mut self, _error: &Error) -> Result<()> { ... }
    fn reset(&mut self) -> Result<()> { ... }
}
A generic module that controls whether timers should execute or not (outside of the normal timer)

Provided Methods

fn pre_timer(&mut self, _timer: TimerInfo) -> Result<Progress>

Decides if a timer should be allowed to execute

fn post_timer(&mut self, _timer: TimerInfo) -> Result<Progress>

Decides what happens after a timer has executed

fn warning(&mut self, _error: &Error) -> Result<()>

Is called when there’s a potentially recoverable error. Can re-throw an unrecoverable error.

fn reset(&mut self) -> Result<()>

If this is called, the counting was reset - clear any cache here